# pyrtition
A simple multithreaded and partitioned Producer/Consumer implementation

![Upload Python Package](https://github.com/jeremylcarter/pyrtition/workflows/Upload%20Python%20Package/badge.svg)
